Utilities — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »

# Utilities

Various utilities get used by Multidrizzle, including some to handle WCS interpretation, trailer file generation, output file generation and interpretation of the MDRIZTAB reference file.

- Utility Functions
- WCS Utilities
- Output Image Generation
- MultiDrizzle Reference Table

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »